@@ -23,11 +23,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <glib.h>
-#include <glib/gprintf.h>
-#include <gtk/gtk.h>
 #include <panel-applet.h>
-#include <string.h>
 
 #include "panel-menu-bar.h"
 #include "utils.h"
@@ -35,7 +31,7 @@
 
 #define APPLET_IID			"OAFIID:GNOME_FileBrowserApplet"
 #define APPLET_FACTORY_IID	"OAFIID:GNOME_FileBrowserApplet_Factory"
-#define VERSION				"0.5.9"
+#define VERSION				"0.6.1"
 
 /******************************************************************************/
 static const gchar file_browser_applet_menu_xml [] =
@@ -45,7 +41,7 @@ static const gchar file_browser_applet_menu_xml [] =
 	"   <menuitem name=\"Help Item\" verb=\"Help\" _label=\"Help\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
 	"   <menuitem name=\"About Item\" verb=\"About\" _label=\"About\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
+	"             pixtype=\"stock\" pixname=\"gtk-about\"/>\n"
 	"</popup>\n";
 /******************************************************************************/
 static gboolean
@@ -61,24 +57,15 @@ file_browser_applet_display_help_dialog (GtkWidget *widget) {
 #ifdef ENABLE_HELP_DOC
 	GError *error = NULL;
 
-	gnome_help_display_desktop_on_screen (
-		  NULL,
-		  "file-browser-applet",
-		  "file-browser-applet",
-		  NULL,
-		  gtk_widget_get_screen (widget),
-		  &error);
-
-	if (error) {
-		utils_show_dialog ("Error",
-						   "Could not display help.",
-						   GTK_MESSAGE_ERROR);
-		g_error_free (error);
-	}
+	gnome_help_display_desktop_on_screen (NULL,
+                                          APP_NAME,
+                                          APP_NAME,
+										  NULL,
+										  gtk_widget_get_screen (widget),
+										  &error);
+	utils_gerror_ok (&error, TRUE);
 #else
-	utils_show_dialog ("Help",
-					   "Sorry, no help or documentation yet...",
-					   GTK_MESSAGE_ERROR);
+	utils_show_dialog (_("Error"), _("Sorry, no help or documentation yet..."), GTK_MESSAGE_ERROR);
 #endif
 	return FALSE;
 }
@@ -86,44 +73,49 @@ file_browser_applet_display_help_dialog (GtkWidget *widget) {
 static gboolean
 file_browser_applet_display_about_dialog (GtkWidget *widget) {
 
-	GdkPixbuf  *pixbuf = NULL;
-	gchar       *file;
 	const gchar *authors[] = {
 		"Axel von Bertoldi <bertoldia@gmail.com>",
 		"",
-		"Contributions by:",
+		_("Contributions by:"),
 		"Ivan N. Zlatev <contact@i-nz.net>",
 		"Stefano Maggiolo <maggiolo@mail.dm.unipi.it>",
-		"Deji Akingunola",
+		"Deji Akingunola <dakingun@gmail.com>",
+		"Serkan Kaba <serkan@gentoo.org>",
+		"Silvio Ricardo Cordeiro <silvioricardoc@gmail.com>",
+        "pachoramos",
 		NULL
 	};
 	const gchar *documenters [] = {
-		"You!!! That's right! You can help!",
+		_("You!!! That's right! You can help!"),
 /*		"Axel von Bertoldi", */
 		NULL
 	};
-	const gchar *translator_credits = _("translator_credits");
+	const gchar *translator_credits = _("You!!! That's right! You can help!");
 
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "file-browser-applet.png", TRUE, NULL);
-	if (file != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-		g_free (file);
-	}
+    static GtkWidget *about_dialog = NULL;
+    if (about_dialog) {
+        gtk_window_set_screen (GTK_WINDOW (about_dialog),
+                gtk_widget_get_screen (widget));
+        gtk_window_present (GTK_WINDOW (about_dialog));
+        return 0;
+    }
+    about_dialog = gtk_about_dialog_new ();
+    g_object_set (about_dialog,	
+                  "name", _("File Browser Applet"),
+                  "version", VERSION,
+                  "copyright", _("Copyright \xc2\xa9 2006-2009 Axel von Bertoldi."),
+                  "comments", _("Browse and open files in your home directory from the panel"),
+                  "authors", authors,
+                  "documenters", documenters,
+                  "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+                  "logo-icon-name", APP_NAME,
+                  "icon-name", APP_NAME,
+                  NULL);
+    gtk_window_set_screen (GTK_WINDOW (about_dialog), gtk_widget_get_screen (widget));
+	g_signal_connect (about_dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &about_dialog);
+	g_signal_connect (about_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+    gtk_widget_show (about_dialog);
 
-	gtk_show_about_dialog (NULL,
-			       "name", _("File Browser Applet"),
-			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 2006-2008 Axel von Bertoldi.",
-			       "comments", _("Browse and open files in your home directory from the panel"),
-			       "authors", authors,
-			       "documenters", documenters,
-			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			       "logo", pixbuf,
-			       NULL);
-
-	if (pixbuf) {
-		g_object_unref (pixbuf);
-	}
 	return 0;
 }
 /******************************************************************************/
@@ -138,6 +130,10 @@ BonoboUIVerb file_browser_applet_menu_verbs [] = {
 static gboolean
 file_browser_applet_create (PanelApplet *applet) {
 
+	setlocale (LC_ALL, "");
+	bindtextdomain (APP_NAME, LOCALEDIR);
+	textdomain (APP_NAME);
+
 	PanelMenuBar* panel_menu_bar = panel_menu_bar_new (applet);
 
 	panel_applet_set_flags (applet,
@@ -162,16 +158,16 @@ file_browser_applet_factory (PanelApplet *applet,
 							 const  gchar *iid,
 							 gpointer data) {
 
-        if (strcmp (iid, APPLET_IID) == 0) {
-            return file_browser_applet_create (applet);
-        }
+	if (strcmp (iid, APPLET_IID) == 0) {
+		return file_browser_applet_create (applet);
+	}
 
-        return FALSE;
+	return FALSE;
 }
 /******************************************************************************/
 PANEL_APPLET_BONOBO_FACTORY (APPLET_FACTORY_IID,
 			     			PANEL_TYPE_APPLET,
-							"file-browser-applet",
+                            APP_NAME,
 							"0",
 							file_browser_applet_factory,
 							NULL)
