@@ -23,21 +23,24 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <glib.h>
 #include <glib/gprintf.h>
 #include <gdk/gdkkeysyms.h>
+#include <panel-applet.h>
+#include <glib-object.h>
+
 #include "panel-menu-bar.h"
 #include "preferences.h"
 #include "menu-browser.h"
 #include "utils.h"
+#include "config.h"
 
-#ifdef ENABLE_GTK_HOTKEY 
+#ifdef LIBGTKHOTKEY_FOUND 
 #include <gtkhotkey.h>
 #endif
 
 /******************************************************************************/
 #define PANEL_MENU_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PANEL_MENU_BAR, PanelMenuBarPrivate))
-#define TOOLTIP_TEXT		"Browse and open files in your home directory"
+#define TOOLTIP_TEXT		_("Browse and open files in your home directory")
 /******************************************************************************/
 struct _PanelMenuBarPrivate {
 	PanelApplet			*applet;
@@ -61,12 +64,11 @@ enum {
 static gpointer panel_menu_bar_parent_class = NULL;
 static void panel_menu_bar_dispose (GObject * obj);
 /******************************************************************************/
-/******************************************************************************/
 void
 panel_menu_bar_edit_prefs (PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	AppletPreferences *prefs = self->priv->prefs;
 	applet_preferences_make_dialog (prefs);
@@ -78,77 +80,73 @@ panel_menu_bar_change_orient (PanelApplet		*applet,
 							  PanelMenuBar		*self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	gint				i;
-	gboolean			text_vertical = FALSE;
-	gdouble				text_angle;
-	gfloat				text_xalign;
-	gfloat				text_yalign;
-	GtkWidget			*menu_browser = NULL;
-	GtkRequisition		requisition;
-	GtkPackDirection	pack_direction;
+	PangoEllipsizeMode	ellipsize_mode = PANGO_ELLIPSIZE_NONE;
+	GtkPackDirection	pack_direction = GTK_PACK_DIRECTION_LTR;
+	double				text_angle = 0.0;
+	float				text_xalign = 0.0;
+	float				text_yalign = 0.5;
 
 	/* update the panel's orientation */
 	self->priv->orientation = orientation;
 
-	/* set the default (horizontal panel) pack and text direction */
-	pack_direction = GTK_PACK_DIRECTION_LTR;
-	text_angle  = 0.0;
-	text_xalign = 0.0;
-	text_yalign = 0.5;
-
-	/* iterate through each menu_item in the menu bar and check it's width */
-	for (i=0; i < self->priv->file_browsers->len; i++) {
-		menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, i));
-		gtk_widget_size_request (menu_browser,
-								 &requisition);
-		/* if any of the menu_items are wider that the panel, set the text to be rotated */
-		if ((!self->priv->text_vertical & (requisition.width  > self->priv->panel_size)) ||
-			( self->priv->text_vertical & (requisition.height > self->priv->panel_size))) {
-			text_vertical = TRUE;
-		}
-	}
-	self->priv->text_vertical = text_vertical;
 	/* set the text and pack direction and */
 	switch (orientation) {
-		case PANEL_APPLET_ORIENT_UP:
-		case PANEL_APPLET_ORIENT_DOWN:
-			self->priv->text_vertical = FALSE;
-			break;
-		case PANEL_APPLET_ORIENT_RIGHT:
+	case PANEL_APPLET_ORIENT_UP:
+	case PANEL_APPLET_ORIENT_DOWN:
+		/* handled by defaults */
+		break;
+	case PANEL_APPLET_ORIENT_RIGHT:
+		if (self->priv->prefs->menu_bar_prefs->horizontal_text) {
 			pack_direction = GTK_PACK_DIRECTION_TTB;
-			if (text_vertical) {
-				pack_direction = GTK_PACK_DIRECTION_BTT;
-				text_angle = 90.0;
-			}
-				text_xalign = 0.5;
-				text_yalign = 0.0;
-			break;
-		case PANEL_APPLET_ORIENT_LEFT:
-			pack_direction = GTK_PACK_DIRECTION_TTB;
-			if (text_vertical) {
-				text_angle = 270.0;
-			}
-				text_xalign = 0.5;
-				text_yalign = 0.0;
-			break;
-		default:
-			g_assert_not_reached ();
-			break;
+			ellipsize_mode = PANGO_ELLIPSIZE_END;
+		}
+		else {
+			pack_direction = GTK_PACK_DIRECTION_BTT;
+			text_angle = 90.0;
+			text_xalign = 0.5;
+			text_yalign = 0.0;
+		}
+		break;
+	case PANEL_APPLET_ORIENT_LEFT:
+		pack_direction = GTK_PACK_DIRECTION_TTB;
+		if (self->priv->prefs->menu_bar_prefs->horizontal_text) {
+			ellipsize_mode = PANGO_ELLIPSIZE_END;
+		}
+		else {
+			text_angle = 270.0;
+			text_xalign = 0.5;
+			text_yalign = 0.0;
+		}
+		break;
+	default:
+		g_assert_not_reached ();
+		break;
 	}
 	/* update the menu_bar pack direction */
 	gtk_menu_bar_set_pack_direction (GTK_MENU_BAR (self), pack_direction);
 	gtk_menu_bar_set_child_pack_direction (GTK_MENU_BAR (self), pack_direction);
 
-	/* update the menu_item text direction */
+	/* update the menu_item ellipsizing */
 	for (i=0; i < self->priv->file_browsers->len; i++) {
-		menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, i));
-		GtkWidget *label = GTK_BIN (menu_browser)->child;
-		gtk_label_set_angle (GTK_LABEL (label), text_angle);
-		gtk_misc_set_alignment (GTK_MISC (label), text_xalign, text_yalign);
+		GtkWidget *menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, i));
+		GtkWidget *label = gtk_bin_get_child (GTK_BIN (menu_browser));
+		if (GTK_IS_LABEL (label)) {
+			gtk_label_set_ellipsize	(GTK_LABEL (label), ellipsize_mode);
+			gtk_label_set_angle		(GTK_LABEL (label), text_angle);
+			gtk_misc_set_alignment	(GTK_MISC  (label), text_xalign, text_yalign);
+		}
 	}
-	return;
+}
+/******************************************************************************/
+static void
+panel_menu_bar_update_orient (PanelMenuBar *self) {
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
+
+	PanelAppletOrient orientation = panel_applet_get_orient (PANEL_APPLET (self->priv->applet));
+	panel_menu_bar_change_orient (self->priv->applet, orientation, self);
 }
 /******************************************************************************/
 static void	/* Taken from the Main Menu Bar Applet */
@@ -158,7 +156,7 @@ panel_menu_bar_size_allocate (GtkWidget *widget,
 
 	PanelMenuBar *self = (PanelMenuBar *)widget;
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	/* WTF!? */
 	allocation->x = 0;
@@ -176,11 +174,7 @@ panel_menu_bar_size_allocate (GtkWidget *widget,
 	GTK_WIDGET_CLASS (panel_menu_bar_parent_class)->size_allocate (widget, allocation);
 
 	PanelAppletOrient orientation = panel_applet_get_orient (PANEL_APPLET (self->priv->applet));
-	panel_menu_bar_change_orient (self->priv->applet,
-								  orientation,
-								  self);
-
-	return;
+	panel_menu_bar_change_orient (self->priv->applet, orientation, self);
 }
 /******************************************************************************/
 static void	/* Taken from the Trash Applet */
@@ -191,7 +185,7 @@ panel_menu_bar_change_background (PanelApplet				*applet,
 								  PanelMenuBar				*self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	GtkRcStyle *rc_style;
 	GtkStyle *style;
@@ -203,34 +197,29 @@ panel_menu_bar_change_background (PanelApplet				*applet,
 	gtk_rc_style_unref (rc_style);
 
 	switch (type) {
-		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg (GTK_WIDGET (self),
-								  GTK_STATE_NORMAL,
-								  color);
-			break;
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (self), GTK_STATE_NORMAL, color);
+		break;
+	case PANEL_PIXMAP_BACKGROUND:
+		style = gtk_style_copy (GTK_WIDGET (self)->style);
+		if (style->bg_pixmap[GTK_STATE_NORMAL] != NULL)
+			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
 
-		case PANEL_PIXMAP_BACKGROUND:
-			style = gtk_style_copy (GTK_WIDGET (self)->style);
-			if (style->bg_pixmap[GTK_STATE_NORMAL] != NULL)
-				g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-
-			style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-			gtk_widget_set_style (GTK_WIDGET (self), style);
-			g_object_unref (style);
-			break;
-
-		case PANEL_NO_BACKGROUND:
-		default:
-			break;
+		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+		gtk_widget_set_style (GTK_WIDGET (self), style);
+		g_object_unref (style);
+		break;
+	case PANEL_NO_BACKGROUND:
+	default:
+		break;
 	}
-	return;
 }
 /******************************************************************************/
 static void
 panel_menu_bar_update_image (PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	GtkWidget *image = NULL;
 	AppletPreferences *a_prefs = self->priv->prefs;
@@ -252,36 +241,34 @@ panel_menu_bar_update_image (PanelMenuBar *self) {
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_browser),
 															icon);
 	}
-	return;
 }
 /******************************************************************************/
-#ifdef ENABLE_GTK_HOTKEY
+#ifdef LIBGTKHOTKEY_FOUND
 static void
 panel_menu_bar_on_hotkey_press (GtkHotkeyInfo *hot_key_info,
 								guint event_time,
 								PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	MenuBrowser *menu_browser = (MenuBrowser *)(g_ptr_array_index (self->priv->file_browsers, 0));
 
 	GTK_MENU_SHELL (self)->active = TRUE;
 	gtk_menu_shell_set_take_focus (GTK_MENU_SHELL (self), TRUE);
-	gtk_menu_shell_select_item (GTK_MENU_SHELL (self),
-								GTK_WIDGET (menu_browser));
+	gtk_menu_shell_select_item (GTK_MENU_SHELL (self), GTK_WIDGET (menu_browser));
 }
 /******************************************************************************/
 static void
 panel_menu_bar_add_keybinding (PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	GError *error = NULL;
 
-	GtkHotkeyInfo *hot_key_info = gtk_hotkey_info_new ("file-browser-applet",
-													   "file-browser-applet",
+	GtkHotkeyInfo *hot_key_info = gtk_hotkey_info_new (APP_NAME,
+                                                       APP_NAME,
                                                        "<Super>h",
 													   NULL);
 
@@ -291,6 +278,7 @@ panel_menu_bar_add_keybinding (PanelMenuBar *self) {
 					  self);
 
 	gtk_hotkey_info_bind (hot_key_info, &error);
+	utils_gerror_ok (&error, TRUE);
 }
 #endif
 /******************************************************************************/
@@ -299,14 +287,11 @@ panel_menu_bar_update_entry (PanelMenuBar *self,
 							 PrefsChangedSignalData *signal_data) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	GtkWidget *menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, signal_data->instance));
 
-	menu_browser_update (MENU_BROWSER (menu_browser),
-						 signal_data->path,
-						 signal_data->label);
-	return;
+	menu_browser_update (MENU_BROWSER (menu_browser), signal_data->path, signal_data->label);
 }
 /******************************************************************************/
 static void
@@ -314,7 +299,7 @@ panel_menu_bar_move_entry (PanelMenuBar *self,
 						   PrefsChangedSignalData *signal_data) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	int new_pos;
 	GtkWidget *menu_browser = NULL;
@@ -327,13 +312,11 @@ panel_menu_bar_move_entry (PanelMenuBar *self,
 		new_pos = signal_data->instance + 1;
 	}
 	else {
-		if (DEBUG) g_printf("shitzer\n");
-		return;
+		if (DEBUG) g_printf("shitzer\n"); return;
 	}
 
 	if (new_pos < 0) {
-		if (DEBUG) g_printf("shitzer\n");
-		return;
+		if (DEBUG) g_printf("shitzer\n"); return;
 	}
 
 	menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, signal_data->instance));
@@ -342,9 +325,7 @@ panel_menu_bar_move_entry (PanelMenuBar *self,
 	if (menu_browser != NULL && menu_browser_affected != NULL) {
 		g_object_ref (G_OBJECT (menu_browser));
 		gtk_container_remove (GTK_CONTAINER (self), menu_browser);
-		gtk_menu_shell_insert (GTK_MENU_SHELL (self),
-							   menu_browser,
-							   new_pos);
+		gtk_menu_shell_insert (GTK_MENU_SHELL (self), menu_browser, new_pos);
 		g_object_unref (G_OBJECT (menu_browser));
 		self->priv->file_browsers->pdata[new_pos] = menu_browser;
 		self->priv->file_browsers->pdata[signal_data->instance] = menu_browser_affected;
@@ -352,15 +333,13 @@ panel_menu_bar_move_entry (PanelMenuBar *self,
 	else {
 		if (DEBUG) g_printf("shitzer\n");
 	}
-	return;
 }
 /******************************************************************************/
 static void
-panel_menu_bar_remove_entry (PanelMenuBar *self,
-							 gint instance) {
+panel_menu_bar_remove_entry (PanelMenuBar *self, gint instance) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	GtkWidget *menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, instance));
 
@@ -371,17 +350,13 @@ panel_menu_bar_remove_entry (PanelMenuBar *self,
 	else {
 		if (DEBUG) g_printf("shitzer\n");
 	}
-
-	return;
 }
 /******************************************************************************/
 static void
-panel_menu_bar_add_entry (PanelMenuBar *self,
-						  gchar *label,
-						  gchar *path) {
+panel_menu_bar_add_entry (PanelMenuBar *self, const gchar *label, const gchar *path) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	GtkWidget *menu_browser = menu_browser_new (path,
 												label,
@@ -390,11 +365,9 @@ panel_menu_bar_add_entry (PanelMenuBar *self,
 	/* add it to the list and to the menu bar*/
 	g_ptr_array_add (self->priv->file_browsers, menu_browser);
 
-	gtk_menu_shell_append (GTK_MENU_SHELL (self),
-						   menu_browser);
+	gtk_menu_shell_append (GTK_MENU_SHELL (self), menu_browser);
 
 	gtk_widget_show_all (menu_browser);
-	return;
 }
 /******************************************************************************/
 static void
@@ -403,29 +376,34 @@ panel_menu_bar_on_preferences_changed (AppletPreferences *a_prefs,
 									   PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	switch (signal_data->signal_id) {
-		case PREFS_SIGNAL_TERMINAL :
-		case PREFS_SIGNAL_SHOW_HIDDEN :
-			break;
-		case PREFS_SIGNAL_SHOW_ICON :
-		case PREFS_SIGNAL_ICON_CHANGED :
-			panel_menu_bar_update_image (self);
-			break;
-		case PREFS_SIGNAL_DIR_MOVE_UP :
-		case PREFS_SIGNAL_DIR_MOVE_DOWN :
-			panel_menu_bar_move_entry (self, signal_data);
-			break;
-		case PREFS_SIGNAL_DIR_CHANGED :
-			panel_menu_bar_update_entry (self, signal_data);
-			break;
-		case PREFS_SIGNAL_DIR_ADD :
-			panel_menu_bar_add_entry (self, signal_data->label, g_strdup (signal_data->path));
-			break;
-		case PREFS_SIGNAL_DIR_DEL :
-			panel_menu_bar_remove_entry (self, signal_data->instance);
-			break;
+	case PREFS_SIGNAL_TERMINAL :
+	case PREFS_SIGNAL_SHOW_HIDDEN :
+		break;
+	case PREFS_SIGNAL_SHOW_ICON :
+	case PREFS_SIGNAL_ICON_CHANGED :
+		panel_menu_bar_update_image (self);
+		break;
+	case PREFS_SIGNAL_DIR_MOVE_UP :
+	case PREFS_SIGNAL_DIR_MOVE_DOWN :
+		panel_menu_bar_move_entry (self, signal_data);
+		break;
+	case PREFS_SIGNAL_DIR_CHANGED :
+		panel_menu_bar_update_entry (self, signal_data);
+		break;
+	case PREFS_SIGNAL_DIR_ADD :
+		panel_menu_bar_add_entry (self, signal_data->label, g_strdup (signal_data->path));
+		break;
+	case PREFS_SIGNAL_DIR_DEL :
+		panel_menu_bar_remove_entry (self, signal_data->instance);
+		break;
+	case PREFS_SIGNAL_HORIZONTAL_TEXT :
+		panel_menu_bar_update_orient (self);
+		break;
+	default:
+		g_assert_not_reached ();
 	}
 	if (DEBUG) g_printf ("caught the signal: %d, ", signal_data->signal_id);
 	if (DEBUG) g_printf ("instance %d, label: %s, path %s\n",
@@ -520,9 +498,18 @@ panel_menu_bar_on_deactivate (GtkWidget *widget,
 							  PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
-	g_object_set (G_OBJECT (widget), "has-tooltip", TRUE, NULL);
+	g_object_set (G_OBJECT (self), "has-tooltip", TRUE, NULL);
+
+	/* this is here because of the solution to the focus problem caused by the
+	 * popped context menu */
+	gtk_widget_set_sensitive (GTK_WIDGET (self), TRUE);
+	gint i;
+	for (i=0; i < self->priv->file_browsers->len; i++) {
+		GtkWidget *menu_browser = (GtkWidget *)(g_ptr_array_index (self->priv->file_browsers, i));
+		gtk_widget_set_sensitive (menu_browser, TRUE);
+	}
 }
 /******************************************************************************/
 gboolean
@@ -531,7 +518,7 @@ panel_menu_bar_on_button_press (GtkWidget *widget,
 								PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_val_if_fail (self == NULL || IS_PANEL_MENU_BAR (self), TRUE);
+	g_return_val_if_fail (IS_PANEL_MENU_BAR (self), TRUE);
 
 	GtkMenuShell *menu_shell = GTK_MENU_SHELL (self);
 
@@ -565,11 +552,11 @@ panel_menu_bar_on_button_press (GtkWidget *widget,
 /******************************************************************************/
 gboolean
 panel_menu_bar_on_key_press (GtkWidget *widget,
-								GdkEventKey *event,
-								PanelMenuBar *self) {
+							 GdkEventKey *event,
+							 PanelMenuBar *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_val_if_fail (self == NULL || IS_PANEL_MENU_BAR (self), TRUE);
+	g_return_val_if_fail (IS_PANEL_MENU_BAR (self), TRUE);
 
 	if ((event->keyval == GDK_Menu) ||
 			 (event->keyval == GDK_F10 &&
@@ -591,12 +578,9 @@ PanelMenuBar*
 panel_menu_bar_new (PanelApplet* applet) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_val_if_fail (applet == NULL || PANEL_IS_APPLET (applet), NULL);
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
 
-	PanelMenuBar *self;
-
-	g_return_val_if_fail (applet == NULL || PANEL_IS_APPLET (applet), NULL);
-	self = g_object_newv (TYPE_PANEL_MENU_BAR, 0, NULL);
+	PanelMenuBar *self = g_object_newv (TYPE_PANEL_MENU_BAR, 0, NULL);
 
 	g_signal_connect (GTK_MENU_BAR (self),
 					  "button_press_event",
@@ -660,7 +644,7 @@ panel_menu_bar_new (PanelApplet* applet) {
 	/* get a handle to the applet context menu */
 	self->priv->bonobo_control = panel_applet_get_control (applet);
 
-#ifdef ENABLE_GTK_HOTKEY
+#ifdef LIBGTKHOTKEY_FOUND
 	/* setup global keybinding */
 	panel_menu_bar_add_keybinding (self);
 #endif
@@ -691,26 +675,23 @@ static void
 panel_menu_bar_init (PanelMenuBar * self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_PANEL_MENU_BAR (self));
+	g_return_if_fail (IS_PANEL_MENU_BAR (self));
 
 	self->priv = PANEL_MENU_BAR_GET_PRIVATE (self);
-	return;
 }
 /******************************************************************************/
 static void
 panel_menu_bar_dispose (GObject *obj) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	PanelMenuBar *self;
 	PanelMenuBarClass *klass;
 /*	GObjectClass * parent_class;*/
 
-	self = PANEL_MENU_BAR (obj);
+	PanelMenuBar *self = PANEL_MENU_BAR (obj);
 	(self->priv->applet == NULL ? NULL : (self->priv->applet = (g_object_unref (self->priv->applet), NULL)));
 	(self->priv->file_browsers == NULL ? NULL : (self->priv->file_browsers = (gpointer)(g_ptr_array_free (self->priv->file_browsers, TRUE))));
 	klass = PANEL_MENU_BAR_CLASS (g_type_class_peek (TYPE_PANEL_MENU_BAR));
 	G_OBJECT_CLASS (panel_menu_bar_parent_class)->dispose (obj);
-	return;
 }
 /******************************************************************************/
 GType
