@@ -23,14 +23,15 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "preferences.h"
-#include "utils.h"
 #include <gtk/gtk.h>
 #include <glade/glade-xml.h>
 #include <glib/gprintf.h>
 #include <stdlib.h>
 
+#include "preferences.h"
+#include "utils.h"
 #include "vfs.h"
+#include "config.h"
 
 /******************************************************************************/
 struct _AppletPreferencesPrivate {
@@ -71,7 +72,7 @@ static void
 applet_preferences_on_show_icon_pressed (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	/* get the new state from the widget and update the prefs structure */
 	self->menu_bar_prefs->show_icon = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
@@ -91,14 +92,36 @@ applet_preferences_on_show_icon_pressed (GtkWidget* widget, AppletPreferences* s
 	/* update the state of the revert button. A pref has changed so the button
 	 * should now be sensitive  */
 	/*gtk_widget_set_sensitive (revert_button, TRUE);*/
-	return;
+}
+/******************************************************************************/
+static void
+applet_preferences_on_horizontal_text_pressed (GtkWidget* widget, AppletPreferences* self) {
+	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
+
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
+
+	/* get the new state from the widget and update the prefs structure. No
+	 * need to let the menu bar or browser object know */
+	self->menu_bar_prefs->horizontal_text = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+
+	PrefsChangedSignalData* signal_data = g_new0 (PrefsChangedSignalData, 1);
+	signal_data->signal_id = PREFS_SIGNAL_HORIZONTAL_TEXT;
+	signal_data->instance  = -1;
+	signal_data->label 	  = NULL;
+	signal_data->path 	  = NULL;
+
+	/* emit the signal so the panel menu bar updates itself */
+	g_signal_emit (G_OBJECT (self),
+				   applet_preferences_signals [PREFS_CHANGED],
+				   0,
+				   signal_data);
 }
 /******************************************************************************/
 static void
 applet_preferences_on_show_hidden_pressed (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	/* get the new state from the widget and update the prefs structure. No
 	 * need to let the menu bar or browser object know */
@@ -107,14 +130,13 @@ applet_preferences_on_show_hidden_pressed (GtkWidget* widget, AppletPreferences*
 	/* update the state of the revert button. A pref has changed so the button
 	 * should now be sensitive  */
 	/*gtk_widget_set_sensitive (revert_button, TRUE);*/
-	return;
 }
 /******************************************************************************/
 static void
 applet_preferences_on_terminal_changed (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	gchar *tmp = NULL;
 
@@ -133,7 +155,7 @@ static void
 applet_preferences_on_editor_changed (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	gchar *tmp = NULL;
 
@@ -152,7 +174,7 @@ static void
 applet_preferences_on_icon_select (GtkWidget* button, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkWidget *file_chooser_dialog;
 	gchar *icon_path = DEFAULT_ICON_PATH;
@@ -160,7 +182,7 @@ applet_preferences_on_icon_select (GtkWidget* button, AppletPreferences* self) {
 	/* set up a file chooser dialog so we can choose the new icon. An icon
 	 * chooser would be better, but that widget is deprecated in the Gnome UI
 	 * lib and GTK equivalent doesn't exist yet */
-	file_chooser_dialog = gtk_file_chooser_dialog_new ("Select Icon",
+	file_chooser_dialog = gtk_file_chooser_dialog_new (_("Select Icon"),
 													   NULL,
 													   GTK_FILE_CHOOSER_ACTION_OPEN,
 													   GTK_STOCK_CANCEL,
@@ -222,7 +244,7 @@ static void
 applet_preferences_save_to_gconf (AppletPreferences *self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	PanelApplet *applet = self->priv->applet;
 	GError* error = NULL;
@@ -232,53 +254,65 @@ applet_preferences_save_to_gconf (AppletPreferences *self) {
 								 KEY_HIDDEN_SHOW,
 								 self->menu_bar_prefs->browser_prefs->show_hidden,
 								 &error);
-	utils_check_gerror (&error);
+	utils_gerror_ok (&error, TRUE);
+
 	/* terminal */
 	panel_applet_gconf_set_string (applet,
 								   KEY_TERMINAL,
 								   self->menu_bar_prefs->browser_prefs->terminal,
 								   &error);
-	utils_check_gerror (&error);
+	utils_gerror_ok (&error, TRUE);
+
 	/* editor */
 	panel_applet_gconf_set_string (applet,
 								   KEY_EDITOR,
 								   self->menu_bar_prefs->browser_prefs->editor,
 								   &error);
-	utils_check_gerror (&error);
+	utils_gerror_ok (&error, TRUE);
+
 	/* the icon */
 	panel_applet_gconf_set_string (applet,
 								   KEY_ICON_NAME,
 								   self->menu_bar_prefs->icon,
 								   &error);
-	utils_check_gerror (&error);
+	utils_gerror_ok (&error, TRUE);
+
 	/* show the icon? */
 	panel_applet_gconf_set_bool (applet,
 								 KEY_ICON_SHOW,
 								 self->menu_bar_prefs->show_icon,
 								 &error);
-	utils_check_gerror (&error);
+	utils_gerror_ok (&error, TRUE);
+
+	/* horizontal text? */
+	panel_applet_gconf_set_bool (applet,
+								 KEY_HORIZONTAL_TEXT,
+								 self->menu_bar_prefs->horizontal_text,
+								 &error);
+	utils_gerror_ok (&error, TRUE);
+
 	/* directory list */
 	panel_applet_gconf_set_list (applet,
 								 KEY_DIR,
 								 GCONF_VALUE_STRING,
 								 self->menu_bar_prefs->dirs,
 								 &error);
-	utils_check_gerror (&error);
+	utils_gerror_ok (&error, TRUE);
+
 	/* labels list */
 	panel_applet_gconf_set_list (applet,
 								 KEY_LABELS,
 								 GCONF_VALUE_STRING,
 								 self->menu_bar_prefs->labels,
 								 &error);
-	utils_check_gerror (&error);
-	return;
+	utils_gerror_ok (&error, TRUE);
 }
 /******************************************************************************/
 static void
 applet_preferences_dialog_response (GtkWidget* window, gint response, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	/* figure out what button closed the dialog and take the appropriate action */
 	switch (response) {
@@ -299,7 +333,6 @@ applet_preferences_dialog_response (GtkWidget* window, gint response, AppletPref
 			gtk_widget_hide (window);
 			break;
 	}
-	return;
 }
 /******************************************************************************/
 static void
@@ -309,7 +342,7 @@ applet_preferences_label_cell_edited (GtkCellRenderer	*cell,
 									  AppletPreferences* self){
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkWidget			*tree_view	= self->priv->tree_view;
 	GtkTreeModel		*model;
@@ -320,19 +353,12 @@ applet_preferences_label_cell_edited (GtkCellRenderer	*cell,
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
 
 	/* get an iterator to the model for the currently selected cell */
-	gtk_tree_model_get_iter_from_string (model,
-										 &iter,
-										 path_string);
+	gtk_tree_model_get_iter_from_string (model, &iter, path_string);
 	/* update the model */
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-						LABEL_COLUMN, new_string,
-						-1);
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, LABEL_COLUMN, new_string, -1);
 
 	/* the path associated with the selection */
-	gtk_tree_model_get (model,
-						&iter,
-						PATH_COLUMN, &path,
-						-1);
+	gtk_tree_model_get (model, &iter, PATH_COLUMN, &path, -1);
 
 	/* create the data structure with the event info to pass to panel_menu_bar */
 	PrefsChangedSignalData* signal_data = g_new0 (PrefsChangedSignalData, 1);
@@ -355,7 +381,6 @@ applet_preferences_label_cell_edited (GtkCellRenderer	*cell,
 
 	/* update the revert button*/
 	/*gtk_widget_set_sensitive (revert_button, TRUE);*/
-	return;
 }
 /******************************************************************************/
 static void
@@ -365,7 +390,7 @@ applet_preferences_path_cell_activated (GtkTreeView		  *tree_view,
 										AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkTreeModel* model;
 	GtkTreeIter	  iter;
@@ -375,17 +400,12 @@ applet_preferences_path_cell_activated (GtkTreeView		  *tree_view,
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
 
 	/* get an iterator to the model for the currently selected cell */
-	gtk_tree_model_get_iter (model,
-							 &iter,
-							 path);
+	gtk_tree_model_get_iter (model, &iter, path);
 	/* the "Path" value for the active cell */
-	gtk_tree_model_get (model,
-						&iter,
-						PATH_COLUMN, &old_path,
-						-1);
+	gtk_tree_model_get (model, &iter, PATH_COLUMN, &old_path, -1);
 
 	/* make a file chooser object to select the new path */
-	file_chooser_dialog = gtk_file_chooser_dialog_new ("Select New Folder To Browse",
+	file_chooser_dialog = gtk_file_chooser_dialog_new (_("Select Folder To Browse"),
 													   NULL,
 													   GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 													   GTK_STOCK_CANCEL,
@@ -394,8 +414,7 @@ applet_preferences_path_cell_activated (GtkTreeView		  *tree_view,
 													   GTK_RESPONSE_ACCEPT,
 													   NULL);
 	/* Set the starting path as the old path */
-	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_chooser_dialog),
-								   old_path);
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_chooser_dialog), old_path);
 	g_free (old_path);
 	/* run the dialog */
 	if (gtk_dialog_run (GTK_DIALOG (file_chooser_dialog)) == GTK_RESPONSE_ACCEPT) {
@@ -403,17 +422,11 @@ applet_preferences_path_cell_activated (GtkTreeView		  *tree_view,
 		gchar* new_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_chooser_dialog));
 		/* only update data if it's not the same as the old one */
 		if (g_ascii_strcasecmp (old_path, new_path)) {
-			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-								PATH_COLUMN, new_path,
-								-1);
-
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter, PATH_COLUMN, new_path, -1);
 
 			/* the label associated with the selection */
 			gchar* label = NULL;
-			gtk_tree_model_get (model,
-								&iter,
-								LABEL_COLUMN, &label,
-								-1);
+			gtk_tree_model_get (model, &iter, LABEL_COLUMN, &label, -1);
 
 			/* get the instance from the iterator */
 			gchar* instance = gtk_tree_model_get_string_from_iter (model, &iter);
@@ -443,22 +456,20 @@ applet_preferences_path_cell_activated (GtkTreeView		  *tree_view,
 		}
 	}
 	gtk_widget_destroy (file_chooser_dialog);
-
-	return;
 }
 /******************************************************************************/
 static void
 applet_preferences_on_add_dir_clicked (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkTreeModel* model;
 	GtkTreeIter	  iter;
 	GtkWidget*	  file_chooser_dialog;
 	GtkWidget*	  tree_view = self->priv->tree_view;
 
-	file_chooser_dialog = gtk_file_chooser_dialog_new ("Select Folder To Add",
+	file_chooser_dialog = gtk_file_chooser_dialog_new (_("Select Folder To Add"),
 													   NULL,
 													   GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 													   GTK_STOCK_CANCEL,
@@ -468,8 +479,7 @@ applet_preferences_on_add_dir_clicked (GtkWidget* widget, AppletPreferences* sel
 													   NULL);
 	/* Set the starting path */
 	gchar* start_path = g_strdup_printf ("%s/*", g_get_home_dir ());
-	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_chooser_dialog),
-								   start_path);
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_chooser_dialog), start_path);
 	g_free (start_path);
 
 	/* check the reply */
@@ -480,9 +490,12 @@ applet_preferences_on_add_dir_clicked (GtkWidget* widget, AppletPreferences* sel
 		/* get the view's model, add a row and set the values */
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW(tree_view));
 		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-							LABEL_COLUMN, label,
-							PATH_COLUMN, dir,
+		gtk_list_store_set (GTK_LIST_STORE(model),
+							&iter,
+							LABEL_COLUMN,
+							label,
+							PATH_COLUMN,
+							dir,
 							-1);
 
 		/* create the data structure with the event info to pass to panel_menu_bar */
@@ -506,14 +519,13 @@ applet_preferences_on_add_dir_clicked (GtkWidget* widget, AppletPreferences* sel
 		/*gtk_widget_set_sensitive (revert_button, TRUE);*/
 	}
 	gtk_widget_destroy (file_chooser_dialog);
-	return;
 }
 /******************************************************************************/
 static void
 applet_preferences_on_rem_dir_clicked (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkTreeSelection	*selection;
 	GtkTreeModel		*model;
@@ -558,15 +570,13 @@ applet_preferences_on_rem_dir_clicked (GtkWidget* widget, AppletPreferences* sel
 		/* update the revert button*/
 		/*gtk_widget_set_sensitive (revert_button, TRUE);*/
 	}
-
-	return;
 }
 /******************************************************************************/
 static void
 applet_preferences_on_down_dir_clicked (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkTreeSelection	*selection = NULL;
 	GtkTreeModel 		*model = NULL;
@@ -586,9 +596,7 @@ applet_preferences_on_down_dir_clicked (GtkWidget* widget, AppletPreferences* se
 			/* get the instance from the iterator */
 			gchar* instance = gtk_tree_model_get_string_from_iter (model, &iter);
 
-			gtk_list_store_swap (GTK_LIST_STORE (model),
-								 &iter,
-								 &iter_next);
+			gtk_list_store_swap (GTK_LIST_STORE (model), &iter, &iter_next);
 
 			/* create the data structure with the event info to pass to panel_menu_bar */
 			PrefsChangedSignalData* signal_data = g_new0 (PrefsChangedSignalData, 1);
@@ -604,22 +612,21 @@ applet_preferences_on_down_dir_clicked (GtkWidget* widget, AppletPreferences* se
 
 			/* emit the signal so the panel menu bar updates itself */
 			g_signal_emit (G_OBJECT (self),
-					applet_preferences_signals [PREFS_CHANGED],
-					0,
-					signal_data);
+						   applet_preferences_signals [PREFS_CHANGED],
+						   0,
+						   signal_data);
 
 			/* update the revert button*/
 			/*gtk_widget_set_sensitive (revert_button, TRUE);*/
 		}
 	}
-	return;
 }
 /******************************************************************************/
 static void
 applet_preferences_on_up_dir_clicked (GtkWidget* widget, AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkTreeSelection	*selection	= NULL;
 	GtkTreeModel 		*model		= NULL;
@@ -644,9 +651,7 @@ applet_preferences_on_up_dir_clicked (GtkWidget* widget, AppletPreferences* self
 			/* get the instance from the iterator */
 			gchar* instance = gtk_tree_model_get_string_from_iter (model, &iter);
 
-			gtk_list_store_swap (GTK_LIST_STORE (model),
-								 &iter,
-								 &iter_prev);
+			gtk_list_store_swap (GTK_LIST_STORE (model), &iter, &iter_prev);
 
 			/* create the data structure with the event info to pass to panel_menu_bar */
 			PrefsChangedSignalData* signal_data = g_new0 (PrefsChangedSignalData, 1);
@@ -671,14 +676,13 @@ applet_preferences_on_up_dir_clicked (GtkWidget* widget, AppletPreferences* self
 		}
 		gtk_tree_path_free (path);
 	}
-	return;
 }
 /******************************************************************************/
 static void
 applet_preferences_create_list_view (AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkTreeIter			iter;
 	GtkListStore		*store;
@@ -688,18 +692,19 @@ applet_preferences_create_list_view (AppletPreferences* self) {
 
 	/* Create a model.  We are using the store model for now, though we
 	* could use any other GtkTreeModel */
-	store = gtk_list_store_new (N_COLUMNS,
-							    G_TYPE_STRING,
-							    G_TYPE_STRING);
+	store = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING);
 
 	/* fill the model with data */
 	GSList* tmp_dir   = self->menu_bar_prefs->dirs;
 	GSList* tmp_label = self->menu_bar_prefs->labels;
 	while (tmp_label && tmp_dir) {
 		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter,
-							LABEL_COLUMN, (gchar *)tmp_label->data,
-							PATH_COLUMN, (gchar *)tmp_dir->data,
+		gtk_list_store_set (store,
+							&iter,
+							LABEL_COLUMN,
+							(gchar *)tmp_label->data,
+							PATH_COLUMN,
+							(gchar *)tmp_dir->data,
 							-1);
 		tmp_dir   = tmp_dir->next;
 		tmp_label = tmp_label->next;
@@ -723,8 +728,10 @@ applet_preferences_create_list_view (AppletPreferences* self) {
 
 	/* Create a column, associating the "text" attribute of the
 	* cell_renderer to the first column of the model */
-	column = gtk_tree_view_column_new_with_attributes ("Label", renderer,
-													   "text", LABEL_COLUMN,
+	column = gtk_tree_view_column_new_with_attributes (_("Label"),
+													   renderer,
+													   "text",
+													   LABEL_COLUMN,
 													   NULL);
 	/* Add the column to the view. */
 	gtk_tree_view_append_column (GTK_TREE_VIEW (self->priv->tree_view), column);
@@ -735,23 +742,23 @@ applet_preferences_create_list_view (AppletPreferences* self) {
 					  "row-activated",
 					  G_CALLBACK (applet_preferences_path_cell_activated),
 					  self);
-	column = gtk_tree_view_column_new_with_attributes ("Path", renderer,
-													   "text", PATH_COLUMN,
+	column = gtk_tree_view_column_new_with_attributes (_("Path"),
+													   renderer,
+													   "text",
+													   PATH_COLUMN,
 													   NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (self->priv->tree_view), column);
 
 	/*put the selection in SINGLE mode */
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(self->priv->tree_view));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-
-	return;
 }
 /******************************************************************************/
 void
 applet_preferences_make_dialog (AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_if_fail (self == NULL || IS_APPLET_PREFERENCES (self));
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
 
 	GtkWidget* window;
     GtkWidget* show_icon;
@@ -759,6 +766,7 @@ applet_preferences_make_dialog (AppletPreferences* self) {
     GtkWidget* show_hidden;
     GtkWidget* terminal;
     GtkWidget* editor;
+    GtkWidget* horizontal_text;
 	MenuBarPrefs* mb_prefs = self->menu_bar_prefs;
 
 	if (self->priv->window == NULL) {
@@ -805,6 +813,15 @@ applet_preferences_make_dialog (AppletPreferences* self) {
 						  G_CALLBACK (applet_preferences_on_show_hidden_pressed),
 						  self);
 
+		/***** horizontal text *****/
+		horizontal_text = glade_xml_get_widget (xml, "horizontal_text_check");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (horizontal_text),
+									  mb_prefs->horizontal_text);
+		g_signal_connect (G_OBJECT (horizontal_text),
+						  "toggled",
+						  G_CALLBACK (applet_preferences_on_horizontal_text_pressed),
+						  self);
+
 		/***** icon *****/
 		show_icon = glade_xml_get_widget (xml, "show_icon_check");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (show_icon),
@@ -859,15 +876,13 @@ applet_preferences_make_dialog (AppletPreferences* self) {
 
 	gtk_widget_show_all (self->priv->window);
 	gtk_window_present (GTK_WINDOW (self->priv->window));
-
-	return;
 }
 /******************************************************************************/
 static MenuBarPrefs*
 applet_preferences_load_from_gconf (PanelApplet* applet) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_val_if_fail (applet == NULL || PANEL_IS_APPLET (applet), NULL);
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
 
 	GError* error = NULL;
 
@@ -878,94 +893,74 @@ applet_preferences_load_from_gconf (PanelApplet* applet) {
 	 * instance. It also check to make sure the values were retrieved properly
 	 * AND that they are valid */
 	panel_applet_add_preferences (applet, "/schemas/apps/file-browser-applet/prefs", &error);
-	if (utils_check_gerror (&error)) return NULL;
+	g_return_val_if_fail (utils_gerror_ok (&error, TRUE), NULL);
 
 	/* show hidden files? */
-	mb_prefs->browser_prefs->show_hidden = panel_applet_gconf_get_bool (applet,
-																	 KEY_HIDDEN_SHOW,
-																	 &error);
-	if (utils_check_gerror (&error)) {
+	mb_prefs->browser_prefs->show_hidden = panel_applet_gconf_get_bool (applet, KEY_HIDDEN_SHOW, &error);
+	if (!utils_gerror_ok (&error, TRUE)) {
 		mb_prefs->browser_prefs->show_hidden = DEFAULT_SHOW_HIDDEN;
-		panel_applet_gconf_set_bool (applet,
-									 KEY_HIDDEN_SHOW,
-									 mb_prefs->browser_prefs->show_hidden,
-									 &error);
+		panel_applet_gconf_set_bool (applet, KEY_HIDDEN_SHOW, mb_prefs->browser_prefs->show_hidden, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
+
 	/* terminal */
-	mb_prefs->browser_prefs->terminal = panel_applet_gconf_get_string (applet,
-																	KEY_TERMINAL,
-																	&error);
-	if (utils_check_gerror (&error) || mb_prefs->browser_prefs->terminal == NULL) {
+	mb_prefs->browser_prefs->terminal = panel_applet_gconf_get_string (applet, KEY_TERMINAL, &error);
+	if (!utils_gerror_ok (&error, TRUE) || mb_prefs->browser_prefs->terminal == NULL) {
 		mb_prefs->browser_prefs->terminal = g_strdup (DEFAULT_TERMINAL);
-		panel_applet_gconf_set_string (applet,
-									   KEY_TERMINAL,
-									   mb_prefs->browser_prefs->terminal,
-									   &error);
+		panel_applet_gconf_set_string (applet, KEY_TERMINAL, mb_prefs->browser_prefs->terminal, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
+
 	/* editor */
-	mb_prefs->browser_prefs->editor = panel_applet_gconf_get_string (applet,
-																	 KEY_EDITOR,
-																	 &error);
-	if (utils_check_gerror (&error) || mb_prefs->browser_prefs->editor == NULL) {
+	mb_prefs->browser_prefs->editor = panel_applet_gconf_get_string (applet, KEY_EDITOR, &error);
+	if (!utils_gerror_ok (&error, TRUE) || mb_prefs->browser_prefs->editor == NULL) {
 		mb_prefs->browser_prefs->editor = g_strdup (DEFAULT_EDITOR);
-		panel_applet_gconf_set_string (applet,
-									   KEY_TERMINAL,
-									   mb_prefs->browser_prefs->editor,
-									   &error);
+		panel_applet_gconf_set_string (applet, KEY_TERMINAL, mb_prefs->browser_prefs->editor, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
 
 	/* the icon */
-	mb_prefs->icon = panel_applet_gconf_get_string (applet,
-												 KEY_ICON_NAME,
-												 &error);
-	if (utils_check_gerror (&error) || mb_prefs->icon == NULL) {
+	mb_prefs->icon = panel_applet_gconf_get_string (applet, KEY_ICON_NAME, &error);
+	if (!utils_gerror_ok (&error, TRUE) || mb_prefs->icon == NULL) {
 		mb_prefs->icon = g_strdup (DEFAULT_ICON);
-		panel_applet_gconf_set_string (applet,
-									   KEY_ICON_NAME,
-									   mb_prefs->icon,
-									   &error);
+		panel_applet_gconf_set_string (applet, KEY_ICON_NAME, mb_prefs->icon, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
 
 	/* show the icon? */
-	mb_prefs->show_icon = panel_applet_gconf_get_bool (applet,
-													KEY_ICON_SHOW,
-													&error);
-	if (utils_check_gerror (&error)) {
+	mb_prefs->show_icon = panel_applet_gconf_get_bool (applet, KEY_ICON_SHOW, &error);
+	if (!utils_gerror_ok (&error, TRUE)) {
 		mb_prefs->show_icon = DEFAULT_SHOW_ICON;
-		panel_applet_gconf_set_bool (applet,
-									 KEY_ICON_SHOW,
-									 mb_prefs->show_icon,
-									 &error);
+		panel_applet_gconf_set_bool (applet, KEY_ICON_SHOW, mb_prefs->show_icon, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
+
+	/* horizontal text ? */
+	mb_prefs->horizontal_text = panel_applet_gconf_get_bool (applet, KEY_HORIZONTAL_TEXT, &error);
+	if (!utils_gerror_ok (&error, TRUE)) {
+		mb_prefs->horizontal_text = DEFAULT_HORIZONTAL_TEXT;
+		panel_applet_gconf_set_bool (applet, KEY_HORIZONTAL_TEXT, mb_prefs->horizontal_text, &error);
+		utils_gerror_ok (&error, TRUE);
+	}
+
 	/* directory list */
-	GSList* dirs = panel_applet_gconf_get_list (applet,
-											   KEY_DIR,
-											   GCONF_VALUE_STRING,
-											   &error);
-	if (utils_check_gerror (&error) || dirs == NULL) {
+	GSList* dirs = panel_applet_gconf_get_list (applet, KEY_DIR, GCONF_VALUE_STRING, &error);
+	if (!utils_gerror_ok (&error, TRUE) || dirs == NULL) {
 		dirs = g_slist_alloc ();
 		dirs->data = g_strdup (DEFAULT_PATH);
 		dirs->next = NULL;
-		panel_applet_gconf_set_list (applet,
-									 KEY_DIR,
-									 GCONF_VALUE_STRING,
-									 dirs,
-									 &error);
+		panel_applet_gconf_set_list (applet, KEY_DIR, GCONF_VALUE_STRING, dirs, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
+
 	/* labels list */
-	GSList* labels = panel_applet_gconf_get_list (applet,
-											     KEY_LABELS,
-											     GCONF_VALUE_STRING,
-											     &error);
-	if (utils_check_gerror (&error) || labels == NULL) {
+	GSList* labels = panel_applet_gconf_get_list (applet, KEY_LABELS, GCONF_VALUE_STRING, &error);
+	if (!utils_gerror_ok (&error, TRUE) || labels == NULL) {
 		labels = g_slist_alloc ();
 		labels->data = g_strdup (DEFAULT_LABEL);
 		labels->next = NULL;
-		panel_applet_gconf_set_list (applet,
-									 KEY_LABELS,
-									 GCONF_VALUE_STRING,
-									 labels,
-									 &error);
+		panel_applet_gconf_set_list (applet, KEY_LABELS, GCONF_VALUE_STRING, labels, &error);
+		utils_gerror_ok (&error, TRUE);
 	}
 	mb_prefs->dirs   = dirs;
 	mb_prefs->labels = labels;
@@ -977,16 +972,14 @@ AppletPreferences*
 applet_preferences_new (PanelApplet* applet) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-	g_return_val_if_fail (applet == NULL || PANEL_IS_APPLET (applet), NULL);
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
 
-	AppletPreferences* self;
-	self = g_object_newv (TYPE_APPLET_PREFERENCES, 0, NULL);
+	AppletPreferences* self = g_object_newv (TYPE_APPLET_PREFERENCES, 0, NULL);
 
 	self->menu_bar_prefs = applet_preferences_load_from_gconf (applet);
 	self->priv->window = NULL;
 	self->priv->applet = applet;
 
-
 	return self;
 }
 /******************************************************************************/
@@ -1001,9 +994,8 @@ applet_preferences_class_init (AppletPreferencesClass* klass) {
 	applet_preferences_signals [PREFS_CHANGED] =
 		g_signal_new ("prefs_changed",
     	              G_TYPE_FROM_CLASS (klass),
-					  G_SIGNAL_NO_HOOKS,
-            	      /*G_STRUCT_OFFSET (AppletPreferencesClass, prefs_changed),*/
-					  0,
+					  G_SIGNAL_RUN_LAST,
+            	      G_STRUCT_OFFSET (AppletPreferencesClass, prefs_changed),
 					  NULL,
 					  NULL,
 				      g_cclosure_marshal_VOID__INT,
@@ -1020,13 +1012,14 @@ static void
 applet_preferences_init (AppletPreferences* self) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
+	g_return_if_fail (IS_APPLET_PREFERENCES (self));
+
 	self->priv = APPLET_PREFERENCES_GET_PRIVATE (self);
 }
 /******************************************************************************/
 static void
 applet_preferences_dispose (GObject* obj) {
-	AppletPreferences* self;
-	self = APPLET_PREFERENCES (obj);
+	AppletPreferences* self = APPLET_PREFERENCES (obj);
 	(self->priv->window == NULL ? NULL : (self->priv->window = (g_object_unref (self->priv->window), NULL)));
 	G_OBJECT_CLASS (applet_preferences_parent_class)->dispose (obj);
 }
