@@ -26,13 +26,9 @@
 #ifndef __PREFERENCES_H__
 #define __PREFERENCES_H__
 
-#include <glib.h>
 #include <glib-object.h>
 #include <panel-applet-gconf.h>
 
-#include "utils.h"
-#include "config.h"
-
 G_BEGIN_DECLS
 
 /******************************************************************************/
@@ -43,22 +39,24 @@ G_BEGIN_DECLS
 #define IS_APPLET_PREFERENCES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLET_PREFERENCES))
 #define APPLET_PREFERENCES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLET_PREFERENCES, AppletPreferencesClass))
 /******************************************************************************/
-#define KEY_DIR			"dirs"
-#define KEY_LABELS		"labels"
-#define KEY_ICON_NAME	"icon"
-#define KEY_ICON_SHOW	"show_icon"
-#define KEY_HIDDEN_SHOW	"show_hidden"
-#define KEY_TERMINAL	"terminal"
-#define KEY_EDITOR		"editor"
+#define KEY_DIR				"dirs"
+#define KEY_LABELS			"labels"
+#define KEY_ICON_NAME		"icon"
+#define KEY_ICON_SHOW		"show_icon"
+#define KEY_HIDDEN_SHOW		"show_hidden"
+#define KEY_TERMINAL		"terminal"
+#define KEY_EDITOR			"editor"
+#define KEY_HORIZONTAL_TEXT	"horizontal_text"
 
 /* default options */
-#define DEFAULT_ICON		"user-home"
-#define DEFAULT_SHOW_ICON	TRUE
-#define DEFAULT_LABEL		"Home"
-#define DEFAULT_PATH		g_get_home_dir ()
-#define DEFAULT_TERMINAL	"gnome-terminal"
-#define DEFAULT_EDITOR		"gedit"
-#define DEFAULT_SHOW_HIDDEN	FALSE
+#define DEFAULT_ICON			"user-home"
+#define DEFAULT_SHOW_ICON		TRUE
+#define DEFAULT_LABEL			"Home"
+#define DEFAULT_PATH			g_get_home_dir ()
+#define DEFAULT_TERMINAL		"gnome-terminal"
+#define DEFAULT_EDITOR			"gedit"
+#define DEFAULT_SHOW_HIDDEN		FALSE
+#define DEFAULT_HORIZONTAL_TEXT	TRUE
 /******************************************************************************/
 typedef struct _BrowserPrefs BrowserPrefs;
 typedef struct _MenuBarPrefs MenuBarPrefs;
@@ -76,6 +74,7 @@ struct _MenuBarPrefs {
 	GSList			*dirs;
 	GSList			*labels;
 	gboolean 		show_icon;
+	gboolean 		horizontal_text;
 	gchar 			*icon;
 	BrowserPrefs	*browser_prefs;
 };
@@ -86,6 +85,7 @@ struct _AppletPreferences {
 };
 struct _AppletPreferencesClass {
 	GObjectClass parent;
+	void (*prefs_changed)(AppletPreferences *a_prefs, PrefsChangedSignalData *signal_data);
 };
 struct _PrefsChangedSignalData {
 	gint	signal_id;
@@ -103,7 +103,8 @@ enum {
 	PREFS_SIGNAL_DIR_MOVE_UP,
 	PREFS_SIGNAL_DIR_MOVE_DOWN,
 	PREFS_SIGNAL_DIR_ADD,
-	PREFS_SIGNAL_DIR_DEL
+	PREFS_SIGNAL_DIR_DEL,
+	PREFS_SIGNAL_HORIZONTAL_TEXT
 };
 /******************************************************************************/
 AppletPreferences*	applet_preferences_new (PanelApplet *applet);
