@@ -24,25 +24,60 @@
  */
 
 #include <glib/gprintf.h>
-#include <string.h>
 
 #include "utils.h"
+#include "config.h"
 
+/******************************************************************************/
+void
+garbage_init (Garbage *garabage) {
+	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
+    
+    if (*garabage == NULL) {
+    	GPtrArray **_garbage = (GPtrArray**)garabage;
+	    *_garbage = g_ptr_array_new();
+    }
+}
+/******************************************************************************/
+void
+garbage_empty (Garbage *garabage, gboolean reuse) {
+	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
+
+    if (*garabage == NULL)
+        return;
+
+	GPtrArray **_garbage = (GPtrArray**)garabage;
+
+	g_ptr_array_foreach (*_garbage, (GFunc)g_free, NULL);
+	g_ptr_array_free (*_garbage, TRUE);
+	*_garbage = reuse ? g_ptr_array_new() : NULL;
+}
+/******************************************************************************/
+void
+garbage_add_item (Garbage garabage, gpointer item) {
+	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
+
+	if (garabage) {
+		GPtrArray *_garbage = (GPtrArray*)garabage;
+		g_ptr_array_add (_garbage, item);
+	}
+}
 /******************************************************************************/
 gboolean
-utils_check_gerror (GError **error) {
+utils_gerror_ok (GError **error, gboolean show_error) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
 	if (*error) {
 		if (DEBUG) g_printf ("error: %s\n", (*error)->message);
-		utils_show_dialog ("Application Error",
-						   (*error)->message,
-						   GTK_MESSAGE_ERROR);
+
+		if (show_error)
+			utils_show_dialog (_("Error"), (*error)->message, GTK_MESSAGE_ERROR);
+
 		g_error_free (*error);
 		*error = NULL;
-		return TRUE;
+		return FALSE;
 	}
-	return FALSE;
+	return TRUE;
 }
 /******************************************************************************/
 void
@@ -53,30 +88,26 @@ utils_show_dialog (const gchar *title, const gchar *message, GtkMessageType type
 												0,
 												type,
 												GTK_BUTTONS_CLOSE,
+												"%s",
 												message);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
-	g_signal_connect (G_OBJECT (dialog), "destroy",
-					  G_CALLBACK (gtk_widget_destroy), dialog);
-    g_signal_connect (G_OBJECT (dialog), "delete_event",
-                      G_CALLBACK (gtk_widget_destroy), dialog);
-	g_signal_connect_swapped (G_OBJECT (dialog),
-							  "response",
-							  G_CALLBACK (gtk_widget_destroy),
-							  dialog);
+	g_signal_connect (G_OBJECT (dialog), "destroy", G_CALLBACK (gtk_widget_destroy), dialog);
+    g_signal_connect (G_OBJECT (dialog), "delete_event", G_CALLBACK (gtk_widget_destroy), dialog);
+	g_signal_connect_swapped (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), dialog);
 	gtk_widget_show_all (dialog);
 
 	return;
 }
 /******************************************************************************/
 GtkWidget*
-utils_get_scaled_image_from_file (gchar *file_name, int size) {
+utils_get_scaled_image_from_file (const gchar *file_name, int size) {
 	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
 
-		GdkPixbuf *pixbuf   = gdk_pixbuf_new_from_file_at_size (file_name,
-															   size,
-															   size,
-															   NULL);
+	GdkPixbuf *pixbuf   = gdk_pixbuf_new_from_file_at_size (file_name,
+															size,
+															size,
+															NULL);
 		if (pixbuf == NULL) return NULL;
 
 		GtkWidget *icon = gtk_image_new_from_pixbuf (pixbuf);
@@ -98,31 +129,18 @@ g_slist_swap_data (GSList *list, guint index) {
 	return list;
 }
 /******************************************************************************/
-gint
-utils_sort_alpha (const gchar **s1,
-				  const gchar **s2) {
-	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
-
-	return g_utf8_collate ((gchar *)*s1, (gchar *)*s2);
+gchar*
+utils_escape_str (const gchar *str, const gchar *old_token, const gchar *new_token) {
+	gchar **tokens = g_strsplit (str, old_token, 0);
+	gchar *escaped_str = g_strjoinv (new_token, tokens);
+	g_strfreev (tokens);
+	return escaped_str;
 }
 /******************************************************************************/
-gchar *
-utils_clamp_file_name (const gchar *file_name, int length, gboolean *clamped) {
-	if (DEBUG) g_printf ("In %s\n", __FUNCTION__);
-
-/* clamped is true if the string is actually clamped */
-	gchar *tmp, *ret;
-
-	if (strlen (file_name) > length) {
-		tmp = g_strndup (file_name, length - 3);
-		ret = g_strdup_printf ("%s...", tmp);
-		g_free (tmp);
-		if (clamped != NULL) *clamped = TRUE;
-		return ret;
-	}
-	else {
-		if (clamped != NULL) *clamped = FALSE;
-		return g_strdup (file_name);
-	}
+gchar**
+g_strv_new (guint size) {
+	gchar **strv = g_new0 (gchar*, size + 1);
+	strv[size] = NULL;
+	return strv;
 }
 /******************************************************************************/
