@@ -26,16 +26,20 @@
 #ifndef UTILS_H
 #define UTILS_H
 
-#include <glib.h>
 #include <gtk/gtk.h>
 
-#include "config.h"
-
-gboolean	utils_check_gerror (GError **error);
+/******************************************************************************/
+typedef GPtrArray *Garbage;
+/******************************************************************************/
+void		garbage_empty (Garbage *garabage, gboolean reuse);
+void		garbage_init  (Garbage *garabage);
+void		garbage_add_item (Garbage garabage, gpointer item);
+/******************************************************************************/
+gboolean	utils_gerror_ok (GError **error, gboolean show_error);
 void		utils_show_dialog (const gchar *title, const gchar *message, GtkMessageType type);
-GtkWidget*	utils_get_scaled_image_from_file (gchar *file_name, int size);
+GtkWidget*	utils_get_scaled_image_from_file (const gchar *file_name, int size);
+gchar*		utils_escape_str (const gchar *str, const gchar *old_token, const gchar *new_token);
 GSList*		g_slist_swap_data (GSList *list, guint index);
-gint		utils_sort_alpha (const gchar **s1, const gchar **s2);
-gchar*		utils_clamp_file_name (const gchar *file_name, int length, gboolean *clamped);
-
+gchar**		g_strv_new (guint size);
+/******************************************************************************/
 #endif
